colorise package
================

.. automodule:: colorise
    :members:
    :undoc-members:
    :show-inheritance:

Subpackages
-----------

.. toctree::

    colorise.nix
    colorise.win

Submodules
----------

colorise.attributes module
--------------------------

.. automodule:: colorise.attributes
    :members:
    :undoc-members:
    :show-inheritance:

colorise.cluts module
---------------------

.. automodule:: colorise.cluts
    :members:
    :undoc-members:
    :show-inheritance:

colorise.color\_tools module
----------------------------

.. automodule:: colorise.color_tools
    :members:
    :undoc-members:
    :show-inheritance:

colorise.error module
---------------------

.. automodule:: colorise.error
    :members:
    :undoc-members:
    :show-inheritance:

colorise.formatter module
-------------------------

.. automodule:: colorise.formatter
    :members:
    :undoc-members:
    :show-inheritance:

colorise.terminal module
------------------------

.. automodule:: colorise.terminal
    :members:
    :undoc-members:
    :show-inheritance:


